/******************************************************************************
 *                                                                            *
 *      FONTSPY.H                                                             *
 *                                                                            *
 *      Header file for C++ and C for communication between user              *
 *      programs and the memory resident portion of FONTSPY 1.20.             *
 *                                                                            *
 *      Copyright (C) Alexander Rautenberg 1990                               *
 *      All rights reserved!                                                  *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 *      The information in this file is NOT necessary for using the FONTSPY   *
 *      program. It is intended for programers who wish to use data from the  *
 *      memory resident program FONTSPY in their own programs.                *
 *                                                                            *
 *      The specifications in this file are valid for all versions of FONTSPY *
 *      from 1.20 on. Earlier versions used another method for gathering data *
 *      for the Font Editor program.                                          *
 *                                                                            *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 *  This product uses the TesSeRact(tm) Ram-Resident Library and supports the *
 *  TesSeRact Standard for Ram-Resident Program Communication. For informa-   *
 *  tion about TesSeRact, contact the TesSeRact Development Team at:          *
 *                                                                            *
 *      TesSeRact Development Team                                            *
 *      1657 The Fairways                                                     *
 *      Suite 101                                                             *
 *      Jenkintown, PA 19046                                                  *
 *      1-215-884-3373                                                        *
 *                                                                            *
 *      Compuserve:     70731.20                                              *
 *      MCIMAIL:        315-5415                                              *
 *                                                                            *
 *  This MCIMAIL Account has been provided to the TesSeRact Development Team  *
 *  by Borland International, Inc. The TesSeRact Development Team is in no    *
 *  way associated with Borland International, Inc. TesSeRact is a trademark  *
 *  of the TesSeRact Development Team.                                        *
 *                                                                            *
 ****************************************************************************** ******************************************************************************
 *                                                                            *
 *      The FONTSPY program uses TesSeRact routines to communicate with       *
 *      other memory resident programs and with DOS application programs      *
 *      If you wish to write a program that utilizes data from FONTSPY, you   *
 *      can use this header file, which provides the necessary types and      *
 *      constants.                                                            *
 *                                                                            *
 *      The publication of this communication interface does not imply the    *
 *      right to copy the header file and distribute it except as part of     *
 *      the complete Font Editor package and under the same conditions as     *
 *      specified for that software. This, of course, applies to the          *
 *      FONTSPY program itself. In particular, no modifications of the files  *
 *      are permissible.                                                      *
 *                                                                            *
 *      After you have checked to see that FONTSPY has been installed, you    *
 *      can call the desired functions using the TesSeRact multiplex          *
 *      interrupt and read the data from the parameter block. This is done    *
 *      by giving FONTSPY a FAR pointer to the parameter of the type struct   *
 *      UserData. Specify the desired function in the type field:             *
 *                                                                            *
 *      Fontspy_GetVersion                                                    *
 *                                                                            *
 *          Returns the version number in the version field - the major       *
 *          version number in the high byte and the subversion number in the  *
 *          low byte. For example: 0x0114 for version 1.20.                   *
 *                                                                            *
 *      Fontspy_GetBuffer                                                     *
 *                                                                            *
 *          Returns the internal memory address in which FONTSPY has stored   *
 *          the character definitions which have been read. The memory        *
 *          segment is 10656 bytes long and structured exactly like the       *
 *          character set files. You can read the definitons from this        *
 *          segment and further process them, but you should not alter any    *
 *          data in memory.                                                   *
 *                                                                            *
 *      Fontspy_DisableUninstall                                              *
 *                                                                            *
 *          Prevents deactivation of FONTSPY. Calling this function will      *
 *          cause the selection of `Deactivate' in the FONTSPY menu to be     *
 *          ignored.                                                          *
 *                                                                            *
 *      Fontspy_EnableUninstall                                               *
 *                                                                            *
 *          Cancels Fontspy_DisableUninstall.                                 *
 *                                                                            *
 *      Fontspy_GetSize                                                       *
 *                                                                            *
 *          Returns the size of the resident program FONTSPY.                 *
 *                                                                            *
 *      If the call is successful, the value Fontspy_OK will appear in the    *
 *      retval field of the parameter block, otherwise Fontspy_Unknown,       *
 *      indicating that you have specified an invalid function number.        *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 *      To determine whether FONTSPY has been loaded, use the Multiplex-      *
 *      interrupt 0x2F with the following register values:                    *
 *                                                                            *
 *          ax:     0x5453      (TesSeRact identifier)                        *
 *          bx:     0x0000                                                    *
 *          cx:     0x0000                                                    *
 *          si:     OFFSET      of the identification string  ("TOSOFTFS")    *
 *          ds:     SEGMENT     of the identification string                  *
 *                                                                            *
 *      If FONTSPY is installed, the register values after the call will be:  *
 *                                                                            *
 *          ax:     0xFFFF                                                    *
 *          cx:     Identifier for FONTSPY                                    *
 *                                                                            *
 *      You can activate FONTSPY with the identifier returned. In order to do *
 *      this, first set the desired values of the parameter block and then    *
 *      call the Multiplex Interrupt 0x2F with:                               *
 *                                                                            *
 *          ax:     0x5453      (TesSeRact-Identifier)                        *
 *          bx:     0x0020                                                    *
 *          cx:     Identifier for FONTSPY                                    *
 *          di:     OFFSET of the parameter block                             *
 *          es:     SEGMENT of the parameter block                            *
 *                                                                            *
 *        If the call is successful, the following value will be returned:    *
 *                                                                            *
 *          ax:      0x0000                                                   *
 *                                                                            *
 *        Any other value indicates that you have passed an                   *
 *        invalid identifier for FONTSPY.                                     *
 *                                                                            *
 ******************************************************************************
 ******************************************************************************/



#if !defined(FONTSPYH)  /* Prevents multiple loading of FONTSPY.H           */
#define FONTSPYH

#if __cplusplus         /* This declaration is only relevant for C++ from   */
extern "C" {            /* Release 2.0 on. For C and for older C++-Versions */
#endif                  /* the declaration should be preceded by:           */
                        /* #define __cplusplus 0                            */



                    /* Function numbers for calling FONTSPY-UserFct.        */
                    /* from other programs.                                 */
#define Fontspy_GetVersion          1
#define Fontspy_GetBuffer           2
#define Fontspy_DisableUninstall    3
#define Fontspy_EnableUninstall     4
#define Fontspy_GetSize             5


                    /* Values returned after call to a FONTSPY-UserFunction */
#define Fontspy_OK          0
#define Fontspy_Unknown     0xFFFF

                    /* Parameter block sent to the FONTSPY-UserFunction      */
struct UserData {
        unsigned    type;       /* Function called                           */
        unsigned    retval;     /* Value returned                            */
        union                   /* Data returned (depending on function      */
            {                   /* called):                                  */
        void far *Font;             /* Address of character set memory       */
        unsigned  version;          /* FONTSPY-Version nummer                */
        unsigned  size;             /* Resident size of FONTSPY              */
#if __cplusplus
        };      /* In C++ unions do not have to be named                     */
#else
        }   data;   /* ...,  in C, they do!                                  */

#endif
        };

#define IDSTRING    "TOSOFTFS"  /* TesSeRact-IdString for FONTSPY            */

#if __cplusplus         /* This declaration is only relevant for C++         */
}                       /* form Release 2.0 on. (see above!)                 */      */
#endif

#endif  /* !defined(FONTSPYH) */
